
import articles.translation

from django.contrib import admin

from modeltranslation.admin import TranslationAdmin

from articles.models import Article


class ArticleAdmin(TranslationAdmin):

    list_display = ['title', 'type']

    list_filter = ['type']


admin.site.register(Article, ArticleAdmin)




from django.conf import settings
from django.utils.translation import ugettext_lazy as _


DEFAULT_ARTICLE_TYPE_CHOICES = (
    ('news', _('News')),
)


ARTICLE_TYPE_CHOICES = getattr(
    settings, 'ARTICLE_TYPE_CHOICES', DEFAULT_ARTICLE_TYPE_CHOICES)


DEFAULT_ARTICLE_TYPE = getattr(settings, 'DEFAULT_ARTICLE_TYPE', None)



# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-06 10:06
from __future__ import unicode_literals

import ckeditor.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Article',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('type', models.CharField(choices=[(b'news', 'News')], default=None, max_length=255, verbose_name='\u0422\u0438\u043f')),
                ('title', models.CharField(max_length=255, verbose_name='\u041d\u0430\u0437\u0432\u0430')),
                ('logo', models.ImageField(blank=True, null=True, upload_to=b'article_logos')),
                ('description', models.CharField(max_length=255, verbose_name='\u041e\u043f\u0438\u0441')),
                ('text', ckeditor.fields.RichTextField(max_length=10000, verbose_name='\u0422\u0435\u043a\u0441\u0442')),
            ],
            options={
                'verbose_name': 'Article',
                'verbose_name_plural': 'Articles',
            },
        ),
    ]




from django.shortcuts import render, get_object_or_404

from pure_pagination import Paginator

from articles.settings import ARTICLE_TYPE_CHOICES
from articles.models import Article


def article_list(request, article_type):

    printable_article_type = dict(ARTICLE_TYPE_CHOICES)[article_type]

    paginator = Paginator(Article.objects.filter(type=article_type), 10)

    context = {
        'printable_article_type': printable_article_type,
        'articles': paginator.page(request.GET.get('page', 1))
    }

    return render(request, 'articles/list.html', context)


def article_info(request, article_type, article_id):

    context = {
        'article': get_object_or_404(Article, type=article_type, id=article_id)
    }

    return render(request, 'articles/info.html', context)




from django.apps import apps
from django import template


register = template.Library()


@register.simple_tag
def get_latest_articles(article_type, count=5):
    return apps.get_model('articles', 'Article').objects.filter(
        type=article_type).order_by('-id')[:count]




from modeltranslation.translator import register, TranslationOptions

from articles.models import Article


@register(Article)
class FlatPageTranslationOptions(TranslationOptions):

    fields = ('title', 'description', 'text', )




from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _


class ArticlesConfig(AppConfig):
    name = 'articles'
    verbose_name = _("Articles")


default_app_config = 'articles.ArticlesConfig'

__version__ = '2.0'




from django.conf.urls import url

from articles.views import article_list, article_info


urlpatterns = [

    url(r'^(?P<article_type>\w+)/$', article_list, name='list'),

    url(r'^(?P<article_type>\w+)/(?P<article_id>\d+)/$', article_info,
        name='info')

]




from django.db import models
from django.utils.translation import ugettext as _
from django.core.urlresolvers import reverse_lazy

from ckeditor_uploader.fields import RichTextUploadingField

from articles.settings import DEFAULT_ARTICLE_TYPE, ARTICLE_TYPE_CHOICES


class Article(models.Model):

    type = models.CharField(
        _('Type'), choices=ARTICLE_TYPE_CHOICES, default=DEFAULT_ARTICLE_TYPE,
        max_length=255)

    title = models.CharField(_('Title'), max_length=255)

    logo = models.ImageField(
        blank=True, null=True, upload_to='article_logos')

    description = models.CharField(_('Description'), max_length=255)

    text = RichTextUploadingField(_('Text'), max_length=10000)

    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        return reverse_lazy('articles:info', kwargs={
            'article_type': self.type,
            'article_id': self.id
        })

    class Meta:
        verbose_name = _('Article')
        verbose_name_plural = _('Articles')
